from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AwsDisplay(_message.Message):
    __slots__ = ["header", "suppress_sound", "night_time", "dusk_time", "sound_type", "headway_valid", "headway_measurement", "lanes_on", "left_ldw_on", "right_ldw_on", "fcw_on", "left_crossing", "right_crossing", "maintenance", "failsafe", "ped_fcw", "ped_in_dz", "headway_warning_level"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUPPRESS_SOUND_FIELD_NUMBER: _ClassVar[int]
    NIGHT_TIME_FIELD_NUMBER: _ClassVar[int]
    DUSK_TIME_FIELD_NUMBER: _ClassVar[int]
    SOUND_TYPE_FIELD_NUMBER: _ClassVar[int]
    HEADWAY_VALID_FIELD_NUMBER: _ClassVar[int]
    HEADWAY_MEASUREMENT_FIELD_NUMBER: _ClassVar[int]
    LANES_ON_FIELD_NUMBER: _ClassVar[int]
    LEFT_LDW_ON_FIELD_NUMBER: _ClassVar[int]
    RIGHT_LDW_ON_FIELD_NUMBER: _ClassVar[int]
    FCW_ON_FIELD_NUMBER: _ClassVar[int]
    LEFT_CROSSING_FIELD_NUMBER: _ClassVar[int]
    RIGHT_CROSSING_FIELD_NUMBER: _ClassVar[int]
    MAINTENANCE_FIELD_NUMBER: _ClassVar[int]
    FAILSAFE_FIELD_NUMBER: _ClassVar[int]
    PED_FCW_FIELD_NUMBER: _ClassVar[int]
    PED_IN_DZ_FIELD_NUMBER: _ClassVar[int]
    HEADWAY_WARNING_LEVEL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    suppress_sound: bool
    night_time: bool
    dusk_time: bool
    sound_type: int
    headway_valid: bool
    headway_measurement: float
    lanes_on: bool
    left_ldw_on: bool
    right_ldw_on: bool
    fcw_on: bool
    left_crossing: bool
    right_crossing: bool
    maintenance: bool
    failsafe: bool
    ped_fcw: bool
    ped_in_dz: bool
    headway_warning_level: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., suppress_sound: bool = ..., night_time: bool = ..., dusk_time: bool = ..., sound_type: _Optional[int] = ..., headway_valid: bool = ..., headway_measurement: _Optional[float] = ..., lanes_on: bool = ..., left_ldw_on: bool = ..., right_ldw_on: bool = ..., fcw_on: bool = ..., left_crossing: bool = ..., right_crossing: bool = ..., maintenance: bool = ..., failsafe: bool = ..., ped_fcw: bool = ..., ped_in_dz: bool = ..., headway_warning_level: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/py_trees_ros_interfaces/srv/introspect_services.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg import service_details_pb2 as make87__messages__ros2_dot_jazzy_dot_py__trees__ros__interfaces_dot_msg_dot_service__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/jazzy/py_trees_ros_interfaces/srv/introspect_services.proto\x12\x36make87_messages_ros2.jazzy.py_trees_ros_interfaces.srv\x1aLmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/service_details.proto\"\x1b\n\x19IntrospectServicesRequest\"}\n\x1aIntrospectServicesResponse\x12_\n\x0fservice_details\x18\x01 \x03(\x0b\x32\x46.make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.ServiceDetailsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.py_trees_ros_interfaces.srv.introspect_services_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_INTROSPECTSERVICESREQUEST']._serialized_start=218
  _globals['_INTROSPECTSERVICESREQUEST']._serialized_end=245
  _globals['_INTROSPECTSERVICESRESPONSE']._serialized_start=247
  _globals['_INTROSPECTSERVICESRESPONSE']._serialized_end=372
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/flexbe_msgs/msg/behavior_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.flexbe_msgs.msg import container_pb2 as make87__messages__ros2_dot_jazzy_dot_flexbe__msgs_dot_msg_dot_container__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/flexbe_msgs/msg/behavior_request.proto\x12*make87_messages_ros2.jazzy.flexbe_msgs.msg\x1a:make87_messages_ros2/jazzy/flexbe_msgs/msg/container.proto\"\xb0\x01\n\x0f\x42\x65haviorRequest\x12\x15\n\rbehavior_name\x18\x01 \x01(\t\x12\x16\n\x0e\x61utonomy_level\x18\x02 \x01(\r\x12\x10\n\x08\x61rg_keys\x18\x03 \x03(\t\x12\x12\n\narg_values\x18\x04 \x03(\t\x12H\n\tstructure\x18\x05 \x03(\x0b\x32\x35.make87_messages_ros2.jazzy.flexbe_msgs.msg.Containerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.flexbe_msgs.msg.behavior_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BEHAVIORREQUEST']._serialized_start=174
  _globals['_BEHAVIORREQUEST']._serialized_end=350
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosbag2_test_msgdefs/msg/complex_msg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rosbag2_test_msgdefs.msg import basic_msg_pb2 as make87__messages__ros2_dot_rolling_dot_rosbag2__test__msgdefs_dot_msg_dot_basic__msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/rosbag2_test_msgdefs/msg/complex_msg.proto\x12\x35make87_messages_ros2.rolling.rosbag2_test_msgdefs.msg\x1a\x45make87_messages_ros2/rolling/rosbag2_test_msgdefs/msg/basic_msg.proto\"X\n\nComplexMsg\x12J\n\x01\x62\x18\x01 \x01(\x0b\x32?.make87_messages_ros2.rolling.rosbag2_test_msgdefs.msg.BasicMsgb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosbag2_test_msgdefs.msg.complex_msg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMPLEXMSG']._serialized_start=201
  _globals['_COMPLEXMSG']._serialized_end=289
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DifferentialMeasurement(_message.Message):
    __slots__ = ["header", "ros2_header", "base_frame_id", "baseline_length", "baseline_length_variance", "heading", "heading_variance", "pitch", "pitch_variance", "roll", "roll_variance", "position", "position_covariance"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    BASE_FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    BASELINE_LENGTH_FIELD_NUMBER: _ClassVar[int]
    BASELINE_LENGTH_VARIANCE_FIELD_NUMBER: _ClassVar[int]
    HEADING_FIELD_NUMBER: _ClassVar[int]
    HEADING_VARIANCE_FIELD_NUMBER: _ClassVar[int]
    PITCH_FIELD_NUMBER: _ClassVar[int]
    PITCH_VARIANCE_FIELD_NUMBER: _ClassVar[int]
    ROLL_FIELD_NUMBER: _ClassVar[int]
    ROLL_VARIANCE_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    POSITION_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    base_frame_id: str
    baseline_length: float
    baseline_length_variance: float
    heading: float
    heading_variance: float
    pitch: float
    pitch_variance: float
    roll: float
    roll_variance: float
    position: _vector3_pb2.Vector3
    position_covariance: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., base_frame_id: _Optional[str] = ..., baseline_length: _Optional[float] = ..., baseline_length_variance: _Optional[float] = ..., heading: _Optional[float] = ..., heading_variance: _Optional[float] = ..., pitch: _Optional[float] = ..., pitch_variance: _Optional[float] = ..., roll: _Optional[float] = ..., roll_variance: _Optional[float] = ..., position: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., position_covariance: _Optional[_Iterable[float]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import ibeo_data_header_pb2 as _ibeo_data_header_pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import scan_point2205_pb2 as _scan_point2205_pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import scanner_info2205_pb2 as _scanner_info2205_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScanData2205(_message.Message):
    __slots__ = ["header", "ros2_header", "ibeo_header", "scan_start_time", "scan_end_time_offset", "fused_scan", "mirror_side", "coordinate_system", "scan_number", "scan_points", "number_of_scanner_infos", "scanner_info_list", "scan_point_list"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    IBEO_HEADER_FIELD_NUMBER: _ClassVar[int]
    SCAN_START_TIME_FIELD_NUMBER: _ClassVar[int]
    SCAN_END_TIME_OFFSET_FIELD_NUMBER: _ClassVar[int]
    FUSED_SCAN_FIELD_NUMBER: _ClassVar[int]
    MIRROR_SIDE_FIELD_NUMBER: _ClassVar[int]
    COORDINATE_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    SCAN_NUMBER_FIELD_NUMBER: _ClassVar[int]
    SCAN_POINTS_FIELD_NUMBER: _ClassVar[int]
    NUMBER_OF_SCANNER_INFOS_FIELD_NUMBER: _ClassVar[int]
    SCANNER_INFO_LIST_FIELD_NUMBER: _ClassVar[int]
    SCAN_POINT_LIST_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    ibeo_header: _ibeo_data_header_pb2.IbeoDataHeader
    scan_start_time: _time_pb2.Time
    scan_end_time_offset: int
    fused_scan: bool
    mirror_side: int
    coordinate_system: int
    scan_number: int
    scan_points: int
    number_of_scanner_infos: int
    scanner_info_list: _containers.RepeatedCompositeFieldContainer[_scanner_info2205_pb2.ScannerInfo2205]
    scan_point_list: _containers.RepeatedCompositeFieldContainer[_scan_point2205_pb2.ScanPoint2205]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., ibeo_header: _Optional[_Union[_ibeo_data_header_pb2.IbeoDataHeader, _Mapping]] = ..., scan_start_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., scan_end_time_offset: _Optional[int] = ..., fused_scan: bool = ..., mirror_side: _Optional[int] = ..., coordinate_system: _Optional[int] = ..., scan_number: _Optional[int] = ..., scan_points: _Optional[int] = ..., number_of_scanner_infos: _Optional[int] = ..., scanner_info_list: _Optional[_Iterable[_Union[_scanner_info2205_pb2.ScannerInfo2205, _Mapping]]] = ..., scan_point_list: _Optional[_Iterable[_Union[_scan_point2205_pb2.ScanPoint2205, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class JointState(_message.Message):
    __slots__ = ["position", "velocity", "effort"]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_FIELD_NUMBER: _ClassVar[int]
    EFFORT_FIELD_NUMBER: _ClassVar[int]
    position: float
    velocity: float
    effort: float
    def __init__(self, position: _Optional[float] = ..., velocity: _Optional[float] = ..., effort: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/nav_relposned9.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/rolling/ublox_msgs/msg/nav_relposned9.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\"\xa9\x03\n\rNavRELPOSNED9\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x11\n\treserved1\x18\x02 \x01(\r\x12\x16\n\x0eref_station_id\x18\x03 \x01(\r\x12\r\n\x05i_tow\x18\x04 \x01(\r\x12\x11\n\trel_pos_n\x18\x05 \x01(\x05\x12\x11\n\trel_pos_e\x18\x06 \x01(\x05\x12\x11\n\trel_pos_d\x18\x07 \x01(\x05\x12\x16\n\x0erel_pos_length\x18\x08 \x01(\x05\x12\x17\n\x0frel_pos_heading\x18\t \x01(\x05\x12\x11\n\treserved2\x18\n \x03(\r\x12\x13\n\x0brel_pos_hpn\x18\x0b \x01(\x05\x12\x13\n\x0brel_pos_hpe\x18\x0c \x01(\x05\x12\x13\n\x0brel_pos_hpd\x18\r \x01(\x05\x12\x19\n\x11rel_pos_hp_length\x18\x0e \x01(\x05\x12\r\n\x05\x61\x63\x63_n\x18\x0f \x01(\r\x12\r\n\x05\x61\x63\x63_e\x18\x10 \x01(\r\x12\r\n\x05\x61\x63\x63_d\x18\x11 \x01(\r\x12\x12\n\nacc_length\x18\x12 \x01(\r\x12\x13\n\x0b\x61\x63\x63_heading\x18\x13 \x01(\r\x12\x11\n\treserved3\x18\x14 \x03(\r\x12\r\n\x05\x66lags\x18\x15 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.nav_relposned9_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NAVRELPOSNED9']._serialized_start=114
  _globals['_NAVRELPOSNED9']._serialized_end=539
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.action_msgs.msg import goal_info_pb2 as _goal_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CancelGoalRequest(_message.Message):
    __slots__ = ["goal_info"]
    GOAL_INFO_FIELD_NUMBER: _ClassVar[int]
    goal_info: _goal_info_pb2.GoalInfo
    def __init__(self, goal_info: _Optional[_Union[_goal_info_pb2.GoalInfo, _Mapping]] = ...) -> None: ...

class CancelGoalResponse(_message.Message):
    __slots__ = ["return_code", "goals_canceling"]
    RETURN_CODE_FIELD_NUMBER: _ClassVar[int]
    GOALS_CANCELING_FIELD_NUMBER: _ClassVar[int]
    return_code: int
    goals_canceling: _containers.RepeatedCompositeFieldContainer[_goal_info_pb2.GoalInfo]
    def __init__(self, return_code: _Optional[int] = ..., goals_canceling: _Optional[_Iterable[_Union[_goal_info_pb2.GoalInfo, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.jazzy.septentrio_gnss_driver.msg import vector_info_geod_pb2 as _vector_info_geod_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BaseVectorGeod(_message.Message):
    __slots__ = ["header", "block_header", "n", "sb_length", "vector_info_geod"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    N_FIELD_NUMBER: _ClassVar[int]
    SB_LENGTH_FIELD_NUMBER: _ClassVar[int]
    VECTOR_INFO_GEOD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    block_header: _block_header_pb2.BlockHeader
    n: int
    sb_length: int
    vector_info_geod: _containers.RepeatedCompositeFieldContainer[_vector_info_geod_pb2.VectorInfoGeod]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., n: _Optional[int] = ..., sb_length: _Optional[int] = ..., vector_info_geod: _Optional[_Iterable[_Union[_vector_info_geod_pb2.VectorInfoGeod, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/py_trees_ros_interfaces/srv/reconfigure_snapshot_stream.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg import snapshot_stream_parameters_pb2 as make87__messages__ros2_dot_jazzy_dot_py__trees__ros__interfaces_dot_msg_dot_snapshot__stream__parameters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXmake87_messages_ros2/jazzy/py_trees_ros_interfaces/srv/reconfigure_snapshot_stream.proto\x12\x36make87_messages_ros2.jazzy.py_trees_ros_interfaces.srv\x1aWmake87_messages_ros2/jazzy/py_trees_ros_interfaces/msg/snapshot_stream_parameters.proto\"\x9c\x01\n ReconfigureSnapshotStreamRequest\x12\x12\n\ntopic_name\x18\x01 \x01(\t\x12\x64\n\nparameters\x18\x02 \x01(\x0b\x32P.make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg.SnapshotStreamParameters\"3\n!ReconfigureSnapshotStreamResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.py_trees_ros_interfaces.srv.reconfigure_snapshot_stream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RECONFIGURESNAPSHOTSTREAMREQUEST']._serialized_start=238
  _globals['_RECONFIGURESNAPSHOTSTREAMREQUEST']._serialized_end=394
  _globals['_RECONFIGURESNAPSHOTSTREAMRESPONSE']._serialized_start=396
  _globals['_RECONFIGURESNAPSHOTSTREAMRESPONSE']._serialized_end=447
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ibeo_msgs/msg/untracked_properties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import contour_point_sigma_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_contour__point__sigma__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import point2_di_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_point2__di__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import point2_dui_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_point2__dui__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/ibeo_msgs/msg/untracked_properties.proto\x12)make87_messages_ros2.humble.ibeo_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x43make87_messages_ros2/humble/ibeo_msgs/msg/contour_point_sigma.proto\x1a\x39make87_messages_ros2/humble/ibeo_msgs/msg/point2_di.proto\x1a:make87_messages_ros2/humble/ibeo_msgs/msg/point2_dui.proto\"\xda\x05\n\x13UntrackedProperties\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12$\n\x1crelative_time_of_measurement\x18\x02 \x01(\r\x12S\n\x16position_closest_point\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.humble.ibeo_msgs.msg.Point2Di\x12L\n\x0fobject_box_size\x18\x04 \x01(\x0b\x32\x33.make87_messages_ros2.humble.ibeo_msgs.msg.Point2Di\x12S\n\x15object_box_size_sigma\x18\x05 \x01(\x0b\x32\x34.make87_messages_ros2.humble.ibeo_msgs.msg.Point2Dui\x12\x1e\n\x16object_box_orientation\x18\x06 \x01(\x05\x12$\n\x1cobject_box_orientation_sigma\x18\x07 \x01(\r\x12V\n\x19tracking_point_coordinate\x18\x08 \x01(\x0b\x32\x33.make87_messages_ros2.humble.ibeo_msgs.msg.Point2Di\x12]\n\x1ftracking_point_coordinate_sigma\x18\t \x01(\x0b\x32\x34.make87_messages_ros2.humble.ibeo_msgs.msg.Point2Dui\x12 \n\x18number_of_contour_points\x18\n \x01(\r\x12X\n\x12\x63ontour_point_list\x18\x0b \x03(\x0b\x32<.make87_messages_ros2.humble.ibeo_msgs.msg.ContourPointSigmab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ibeo_msgs.msg.untracked_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UNTRACKEDPROPERTIES']._serialized_start=339
  _globals['_UNTRACKEDPROPERTIES']._serialized_end=1069
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_with_covariance_stamped_pb2 as _pose_with_covariance_stamped_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetPoseRequest(_message.Message):
    __slots__ = ["pose"]
    POSE_FIELD_NUMBER: _ClassVar[int]
    pose: _pose_with_covariance_stamped_pb2.PoseWithCovarianceStamped
    def __init__(self, pose: _Optional[_Union[_pose_with_covariance_stamped_pb2.PoseWithCovarianceStamped, _Mapping]] = ...) -> None: ...

class SetPoseResponse(_message.Message):
    __slots__ = ["success", "message"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    message: str
    def __init__(self, success: bool = ..., message: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.novatel_gps_msgs.msg import novatel_message_header_pb2 as _novatel_message_header_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Inspva(_message.Message):
    __slots__ = ["header", "novatel_msg_header", "week", "seconds", "latitude", "longitude", "height", "north_velocity", "east_velocity", "up_velocity", "roll", "pitch", "azimuth", "status"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NOVATEL_MSG_HEADER_FIELD_NUMBER: _ClassVar[int]
    WEEK_FIELD_NUMBER: _ClassVar[int]
    SECONDS_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    NORTH_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    EAST_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    UP_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    ROLL_FIELD_NUMBER: _ClassVar[int]
    PITCH_FIELD_NUMBER: _ClassVar[int]
    AZIMUTH_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    novatel_msg_header: _novatel_message_header_pb2.NovatelMessageHeader
    week: int
    seconds: float
    latitude: float
    longitude: float
    height: float
    north_velocity: float
    east_velocity: float
    up_velocity: float
    roll: float
    pitch: float
    azimuth: float
    status: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., novatel_msg_header: _Optional[_Union[_novatel_message_header_pb2.NovatelMessageHeader, _Mapping]] = ..., week: _Optional[int] = ..., seconds: _Optional[float] = ..., latitude: _Optional[float] = ..., longitude: _Optional[float] = ..., height: _Optional[float] = ..., north_velocity: _Optional[float] = ..., east_velocity: _Optional[float] = ..., up_velocity: _Optional[float] = ..., roll: _Optional[float] = ..., pitch: _Optional[float] = ..., azimuth: _Optional[float] = ..., status: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/automotive_platform_msgs/msg/speed_pedals.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/humble/automotive_platform_msgs/msg/speed_pedals.proto\x12\x38make87_messages_ros2.humble.automotive_platform_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xb1\x01\n\x0bSpeedPedals\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0c\n\x04mode\x18\x03 \x01(\r\x12\x10\n\x08throttle\x18\x04 \x01(\x02\x12\r\n\x05\x62rake\x18\x05 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.automotive_platform_msgs.msg.speed_pedals_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SPEEDPEDALS']._serialized_start=228
  _globals['_SPEEDPEDALS']._serialized_end=405
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CameraGetFocusRingRangeRequest(_message.Message):
    __slots__ = ["header", "payload_index"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_INDEX_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    payload_index: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., payload_index: _Optional[int] = ...) -> None: ...

class CameraGetFocusRingRangeResponse(_message.Message):
    __slots__ = ["header", "success", "min_value", "max_value"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MIN_VALUE_FIELD_NUMBER: _ClassVar[int]
    MAX_VALUE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    min_value: int
    max_value: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., min_value: _Optional[int] = ..., max_value: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CfgTMODE3(_message.Message):
    __slots__ = ["version", "reserved1", "flags", "ecef_x_or_lat", "ecef_y_or_lon", "ecef_z_or_alt", "ecef_x_or_lat_hp", "ecef_y_or_lon_hp", "ecef_z_or_alt_hp", "reserved2", "fixed_pos_acc", "svin_min_dur", "svin_acc_limit", "reserved3"]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    ECEF_X_OR_LAT_FIELD_NUMBER: _ClassVar[int]
    ECEF_Y_OR_LON_FIELD_NUMBER: _ClassVar[int]
    ECEF_Z_OR_ALT_FIELD_NUMBER: _ClassVar[int]
    ECEF_X_OR_LAT_HP_FIELD_NUMBER: _ClassVar[int]
    ECEF_Y_OR_LON_HP_FIELD_NUMBER: _ClassVar[int]
    ECEF_Z_OR_ALT_HP_FIELD_NUMBER: _ClassVar[int]
    RESERVED2_FIELD_NUMBER: _ClassVar[int]
    FIXED_POS_ACC_FIELD_NUMBER: _ClassVar[int]
    SVIN_MIN_DUR_FIELD_NUMBER: _ClassVar[int]
    SVIN_ACC_LIMIT_FIELD_NUMBER: _ClassVar[int]
    RESERVED3_FIELD_NUMBER: _ClassVar[int]
    version: int
    reserved1: int
    flags: int
    ecef_x_or_lat: int
    ecef_y_or_lon: int
    ecef_z_or_alt: int
    ecef_x_or_lat_hp: int
    ecef_y_or_lon_hp: int
    ecef_z_or_alt_hp: int
    reserved2: int
    fixed_pos_acc: int
    svin_min_dur: int
    svin_acc_limit: int
    reserved3: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, version: _Optional[int] = ..., reserved1: _Optional[int] = ..., flags: _Optional[int] = ..., ecef_x_or_lat: _Optional[int] = ..., ecef_y_or_lon: _Optional[int] = ..., ecef_z_or_alt: _Optional[int] = ..., ecef_x_or_lat_hp: _Optional[int] = ..., ecef_y_or_lon_hp: _Optional[int] = ..., ecef_z_or_alt_hp: _Optional[int] = ..., reserved2: _Optional[int] = ..., fixed_pos_acc: _Optional[int] = ..., svin_min_dur: _Optional[int] = ..., svin_acc_limit: _Optional[int] = ..., reserved3: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/srv/endpoint_add.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/mavros_msgs/srv/endpoint_add.proto\x12,make87_messages_ros2.rolling.mavros_msgs.srv\"/\n\x12\x45ndpointAddRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\r\"E\n\x13\x45ndpointAddResponse\x12\x12\n\nsuccessful\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.srv.endpoint_add_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ENDPOINTADDREQUEST']._serialized_start=113
  _globals['_ENDPOINTADDREQUEST']._serialized_end=160
  _globals['_ENDPOINTADDRESPONSE']._serialized_start=162
  _globals['_ENDPOINTADDRESPONSE']._serialized_end=231
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.ds_dbw_msgs.msg import system_state_pb2 as _system_state_pb2
from make87_messages_ros2.humble.ds_dbw_msgs.msg import system_sync_mode_pb2 as _system_sync_mode_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SystemReport(_message.Message):
    __slots__ = ["header", "ros2_header", "inhibit", "validate_cmd_crc_rc", "system_sync_mode", "state", "reason_disengage", "reason_not_ready", "reason_disengage_str", "reason_not_ready_str", "btn_enable", "btn_disable", "lockout", "override", "ready", "enabled", "fault", "bad_crc", "bad_rc"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    INHIBIT_FIELD_NUMBER: _ClassVar[int]
    VALIDATE_CMD_CRC_RC_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_SYNC_MODE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    REASON_DISENGAGE_FIELD_NUMBER: _ClassVar[int]
    REASON_NOT_READY_FIELD_NUMBER: _ClassVar[int]
    REASON_DISENGAGE_STR_FIELD_NUMBER: _ClassVar[int]
    REASON_NOT_READY_STR_FIELD_NUMBER: _ClassVar[int]
    BTN_ENABLE_FIELD_NUMBER: _ClassVar[int]
    BTN_DISABLE_FIELD_NUMBER: _ClassVar[int]
    LOCKOUT_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    READY_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    FAULT_FIELD_NUMBER: _ClassVar[int]
    BAD_CRC_FIELD_NUMBER: _ClassVar[int]
    BAD_RC_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    inhibit: bool
    validate_cmd_crc_rc: bool
    system_sync_mode: _system_sync_mode_pb2.SystemSyncMode
    state: _system_state_pb2.SystemState
    reason_disengage: int
    reason_not_ready: int
    reason_disengage_str: str
    reason_not_ready_str: str
    btn_enable: bool
    btn_disable: bool
    lockout: bool
    override: bool
    ready: bool
    enabled: bool
    fault: bool
    bad_crc: bool
    bad_rc: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., inhibit: bool = ..., validate_cmd_crc_rc: bool = ..., system_sync_mode: _Optional[_Union[_system_sync_mode_pb2.SystemSyncMode, _Mapping]] = ..., state: _Optional[_Union[_system_state_pb2.SystemState, _Mapping]] = ..., reason_disengage: _Optional[int] = ..., reason_not_ready: _Optional[int] = ..., reason_disengage_str: _Optional[str] = ..., reason_not_ready_str: _Optional[str] = ..., btn_enable: bool = ..., btn_disable: bool = ..., lockout: bool = ..., override: bool = ..., ready: bool = ..., enabled: bool = ..., fault: bool = ..., bad_crc: bool = ..., bad_rc: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.humble.smacc2_msgs.msg import smacc_transition_pb2 as _smacc_transition_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SmaccTransitionLogEntry(_message.Message):
    __slots__ = ["header", "timestamp", "transition"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TRANSITION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    timestamp: _time_pb2.Time
    transition: _smacc_transition_pb2.SmaccTransition
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., transition: _Optional[_Union[_smacc_transition_pb2.SmaccTransition, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.diagnostic_msgs.msg import key_value_pb2 as _key_value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CalculateWhiteBalanceRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CalculateWhiteBalanceResponse(_message.Message):
    __slots__ = ["is_successful", "balance_ratios"]
    IS_SUCCESSFUL_FIELD_NUMBER: _ClassVar[int]
    BALANCE_RATIOS_FIELD_NUMBER: _ClassVar[int]
    is_successful: bool
    balance_ratios: _containers.RepeatedCompositeFieldContainer[_key_value_pb2.KeyValue]
    def __init__(self, is_successful: bool = ..., balance_ratios: _Optional[_Iterable[_Union[_key_value_pb2.KeyValue, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PosCovCartesian(_message.Message):
    __slots__ = ["header", "block_header", "mode", "error", "cov_xx", "cov_yy", "cov_zz", "cov_bb", "cov_xy", "cov_xz", "cov_xb", "cov_yz", "cov_yb", "cov_zb"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    COV_XX_FIELD_NUMBER: _ClassVar[int]
    COV_YY_FIELD_NUMBER: _ClassVar[int]
    COV_ZZ_FIELD_NUMBER: _ClassVar[int]
    COV_BB_FIELD_NUMBER: _ClassVar[int]
    COV_XY_FIELD_NUMBER: _ClassVar[int]
    COV_XZ_FIELD_NUMBER: _ClassVar[int]
    COV_XB_FIELD_NUMBER: _ClassVar[int]
    COV_YZ_FIELD_NUMBER: _ClassVar[int]
    COV_YB_FIELD_NUMBER: _ClassVar[int]
    COV_ZB_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    block_header: _block_header_pb2.BlockHeader
    mode: int
    error: int
    cov_xx: float
    cov_yy: float
    cov_zz: float
    cov_bb: float
    cov_xy: float
    cov_xz: float
    cov_xb: float
    cov_yz: float
    cov_yb: float
    cov_zb: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., mode: _Optional[int] = ..., error: _Optional[int] = ..., cov_xx: _Optional[float] = ..., cov_yy: _Optional[float] = ..., cov_zz: _Optional[float] = ..., cov_bb: _Optional[float] = ..., cov_xy: _Optional[float] = ..., cov_xz: _Optional[float] = ..., cov_xb: _Optional[float] = ..., cov_yz: _Optional[float] = ..., cov_yb: _Optional[float] = ..., cov_zb: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_pb2 as _pose_with_covariance_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GeoreferencingMetadata(_message.Message):
    __slots__ = ["header", "valid", "t_enu_to_map", "t_enu_to_utm", "latitude", "longitude", "height", "utm_zone", "utm_band"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VALID_FIELD_NUMBER: _ClassVar[int]
    T_ENU_TO_MAP_FIELD_NUMBER: _ClassVar[int]
    T_ENU_TO_UTM_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    UTM_ZONE_FIELD_NUMBER: _ClassVar[int]
    UTM_BAND_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    valid: bool
    t_enu_to_map: _pose_with_covariance_pb2.PoseWithCovariance
    t_enu_to_utm: _pose_pb2.Pose
    latitude: float
    longitude: float
    height: float
    utm_zone: int
    utm_band: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., valid: bool = ..., t_enu_to_map: _Optional[_Union[_pose_with_covariance_pb2.PoseWithCovariance, _Mapping]] = ..., t_enu_to_utm: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., latitude: _Optional[float] = ..., longitude: _Optional[float] = ..., height: _Optional[float] = ..., utm_zone: _Optional[int] = ..., utm_band: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/raw_micro_scan_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import application_data_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_application__data__pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import data_header_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_data__header__pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import derived_values_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_derived__values__pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import general_system_state_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_general__system__state__pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import intrusion_data_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_intrusion__data__pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import measurement_data_pb2 as make87__messages__ros2_dot_jazzy_dot_sick__safetyscanners2__interfaces_dot_msg_dot_measurement__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/raw_micro_scan_data.proto\x12>make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg\x1aUmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/application_data.proto\x1aPmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/data_header.proto\x1aSmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/derived_values.proto\x1aYmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/general_system_state.proto\x1aSmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/intrusion_data.proto\x1aUmake87_messages_ros2/jazzy/sick_safetyscanners2_interfaces/msg/measurement_data.proto\"\x84\x05\n\x10RawMicroScanData\x12Z\n\x06header\x18\x01 \x01(\x0b\x32J.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.DataHeader\x12\x65\n\x0e\x64\x65rived_values\x18\x02 \x01(\x0b\x32M.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.DerivedValues\x12p\n\x14general_system_state\x18\x03 \x01(\x0b\x32R.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.GeneralSystemState\x12i\n\x10measurement_data\x18\x04 \x01(\x0b\x32O.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.MeasurementData\x12\x65\n\x0eintrusion_data\x18\x05 \x01(\x0b\x32M.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.IntrusionData\x12i\n\x10\x61pplication_data\x18\x06 \x01(\x0b\x32O.make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.ApplicationDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg.raw_micro_scan_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RAWMICROSCANDATA']._serialized_start=674
  _globals['_RAWMICROSCANDATA']._serialized_end=1318
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_receiver_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/rolling/novatel_gps_msgs/msg/novatel_receiver_status.proto\x12\x31make87_messages_ros2.rolling.novatel_gps_msgs.msg\"\xc3\x05\n\x15NovatelReceiverStatus\x12\x1c\n\x14original_status_code\x18\x01 \x01(\r\x12\x12\n\nerror_flag\x18\x02 \x01(\x08\x12\x18\n\x10temperature_flag\x18\x03 \x01(\x08\x12\x1b\n\x13voltage_supply_flag\x18\x04 \x01(\x08\x12\x17\n\x0f\x61ntenna_powered\x18\x05 \x01(\x08\x12\x17\n\x0f\x61ntenna_is_open\x18\x06 \x01(\x08\x12\x1a\n\x12\x61ntenna_is_shorted\x18\x07 \x01(\x08\x12\x19\n\x11\x63pu_overload_flag\x18\x08 \x01(\x08\x12\x1b\n\x13\x63om1_buffer_overrun\x18\t \x01(\x08\x12\x1b\n\x13\x63om2_buffer_overrun\x18\n \x01(\x08\x12\x1b\n\x13\x63om3_buffer_overrun\x18\x0b \x01(\x08\x12\x1a\n\x12usb_buffer_overrun\x18\x0c \x01(\x08\x12\x14\n\x0crf1_agc_flag\x18\r \x01(\x08\x12\x14\n\x0crf2_agc_flag\x18\x0e \x01(\x08\x12\x14\n\x0c\x61lmanac_flag\x18\x0f \x01(\x08\x12\x1e\n\x16position_solution_flag\x18\x10 \x01(\x08\x12\x1b\n\x13position_fixed_flag\x18\x11 \x01(\x08\x12%\n\x1d\x63lock_steering_status_enabled\x18\x12 \x01(\x08\x12\x18\n\x10\x63lock_model_flag\x18\x13 \x01(\x08\x12%\n\x1doemv_external_oscillator_flag\x18\x14 \x01(\x08\x12\x1e\n\x16software_resource_flag\x18\x15 \x01(\x08\x12\x1e\n\x16\x61ux1_status_event_flag\x18\x16 \x01(\x08\x12\x1e\n\x16\x61ux2_status_event_flag\x18\x17 \x01(\x08\x12\x1e\n\x16\x61ux3_status_event_flag\x18\x18 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.novatel_gps_msgs.msg.novatel_receiver_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NOVATELRECEIVERSTATUS']._serialized_start=135
  _globals['_NOVATELRECEIVERSTATUS']._serialized_end=842
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/motion_sequence_response.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_robot__state__pb2
from make87_messages_ros2.jazzy.moveit_msgs.msg import robot_trajectory_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_robot__trajectory__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/jazzy/moveit_msgs/msg/motion_sequence_response.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/move_it_error_codes.proto\x1a<make87_messages_ros2/jazzy/moveit_msgs/msg/robot_state.proto\x1a\x41make87_messages_ros2/jazzy/moveit_msgs/msg/robot_trajectory.proto\"\xac\x02\n\x16MotionSequenceResponse\x12P\n\nerror_code\x18\x01 \x01(\x0b\x32<.make87_messages_ros2.jazzy.moveit_msgs.msg.MoveItErrorCodes\x12N\n\x0esequence_start\x18\x02 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.moveit_msgs.msg.RobotState\x12Y\n\x14planned_trajectories\x18\x03 \x03(\x0b\x32;.make87_messages_ros2.jazzy.moveit_msgs.msg.RobotTrajectory\x12\x15\n\rplanning_time\x18\x04 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.motion_sequence_response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MOTIONSEQUENCERESPONSE']._serialized_start=321
  _globals['_MOTIONSEQUENCERESPONSE']._serialized_end=621
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/marti_nav_msgs/srv/save_route.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.marti_nav_msgs.msg import route_pb2 as make87__messages__ros2_dot_jazzy_dot_marti__nav__msgs_dot_msg_dot_route__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/marti_nav_msgs/srv/save_route.proto\x12-make87_messages_ros2.jazzy.marti_nav_msgs.srv\x1a\x39make87_messages_ros2/jazzy/marti_nav_msgs/msg/route.proto\"\x86\x01\n\x10SaveRouteRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04guid\x18\x02 \x01(\t\x12\x43\n\x05route\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.marti_nav_msgs.msg.Route\x12\x11\n\tthumbnail\x18\x04 \x01(\t\"5\n\x11SaveRouteResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.marti_nav_msgs.srv.save_route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SAVEROUTEREQUEST']._serialized_start=173
  _globals['_SAVEROUTEREQUEST']._serialized_end=307
  _globals['_SAVEROUTERESPONSE']._serialized_start=309
  _globals['_SAVEROUTERESPONSE']._serialized_end=362
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NavDOP(_message.Message):
    __slots__ = ["header", "i_tow", "g_dop", "p_dop", "t_dop", "v_dop", "h_dop", "n_dop", "e_dop"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    G_DOP_FIELD_NUMBER: _ClassVar[int]
    P_DOP_FIELD_NUMBER: _ClassVar[int]
    T_DOP_FIELD_NUMBER: _ClassVar[int]
    V_DOP_FIELD_NUMBER: _ClassVar[int]
    H_DOP_FIELD_NUMBER: _ClassVar[int]
    N_DOP_FIELD_NUMBER: _ClassVar[int]
    E_DOP_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    i_tow: int
    g_dop: int
    p_dop: int
    t_dop: int
    v_dop: int
    h_dop: int
    n_dop: int
    e_dop: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., i_tow: _Optional[int] = ..., g_dop: _Optional[int] = ..., p_dop: _Optional[int] = ..., t_dop: _Optional[int] = ..., v_dop: _Optional[int] = ..., h_dop: _Optional[int] = ..., n_dop: _Optional[int] = ..., e_dop: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/srv/grasp_planning.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import collision_object_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_collision__object__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import grasp_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_grasp__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/moveit_msgs/srv/grasp_planning.proto\x12+make87_messages_ros2.humble.moveit_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x42make87_messages_ros2/humble/moveit_msgs/msg/collision_object.proto\x1a\x37make87_messages_ros2/humble/moveit_msgs/msg/grasp.proto\x1a\x45make87_messages_ros2/humble/moveit_msgs/msg/move_it_error_codes.proto\"\xe7\x02\n\x14GraspPlanningRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12L\n\x06target\x18\x03 \x01(\x0b\x32<.make87_messages_ros2.humble.moveit_msgs.msg.CollisionObject\x12\x18\n\x10support_surfaces\x18\x04 \x03(\t\x12L\n\x10\x63\x61ndidate_grasps\x18\x05 \x03(\x0b\x32\x32.make87_messages_ros2.humble.moveit_msgs.msg.Grasp\x12W\n\x11movable_obstacles\x18\x06 \x03(\x0b\x32<.make87_messages_ros2.humble.moveit_msgs.msg.CollisionObject\"\xdc\x01\n\x15GraspPlanningResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x42\n\x06grasps\x18\x02 \x03(\x0b\x32\x32.make87_messages_ros2.humble.moveit_msgs.msg.Grasp\x12Q\n\nerror_code\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.humble.moveit_msgs.msg.MoveItErrorCodesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.srv.grasp_planning_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GRASPPLANNINGREQUEST']._serialized_start=345
  _globals['_GRASPPLANNINGREQUEST']._serialized_end=704
  _globals['_GRASPPLANNINGRESPONSE']._serialized_start=707
  _globals['_GRASPPLANNINGRESPONSE']._serialized_end=927
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/turtlesim_msgs/srv/kill.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/rolling/turtlesim_msgs/srv/kill.proto\x12/make87_messages_ros2.rolling.turtlesim_msgs.srv\"\x1b\n\x0bKillRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x0e\n\x0cKillResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.turtlesim_msgs.srv.kill_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_KILLREQUEST']._serialized_start=111
  _globals['_KILLREQUEST']._serialized_end=138
  _globals['_KILLRESPONSE']._serialized_start=140
  _globals['_KILLRESPONSE']._serialized_end=154
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.octomap_msgs.msg import octomap_pb2 as _octomap_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetOctomapRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetOctomapResponse(_message.Message):
    __slots__ = ["map"]
    MAP_FIELD_NUMBER: _ClassVar[int]
    map: _octomap_pb2.Octomap
    def __init__(self, map: _Optional[_Union[_octomap_pb2.Octomap, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.marti_common_msgs.msg import key_value_pb2 as _key_value_pb2
from make87_messages_ros2.jazzy.marti_nav_msgs.msg import route_point_pb2 as _route_point_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Route(_message.Message):
    __slots__ = ["header", "route_points", "properties"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROUTE_POINTS_FIELD_NUMBER: _ClassVar[int]
    PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    route_points: _containers.RepeatedCompositeFieldContainer[_route_point_pb2.RoutePoint]
    properties: _containers.RepeatedCompositeFieldContainer[_key_value_pb2.KeyValue]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., route_points: _Optional[_Iterable[_Union[_route_point_pb2.RoutePoint, _Mapping]]] = ..., properties: _Optional[_Iterable[_Union[_key_value_pb2.KeyValue, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/shape_msgs/msg/solid_primitive.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import polygon_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_polygon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/shape_msgs/msg/solid_primitive.proto\x12+make87_messages_ros2.rolling.shape_msgs.msg\x1a<make87_messages_ros2/rolling/geometry_msgs/msg/polygon.proto\"|\n\x0eSolidPrimitive\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x12\n\ndimensions\x18\x02 \x03(\x01\x12H\n\x07polygon\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Polygonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.shape_msgs.msg.solid_primitive_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SOLIDPRIMITIVE']._serialized_start=176
  _globals['_SOLIDPRIMITIVE']._serialized_end=300
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VisionInfo(_message.Message):
    __slots__ = ["header", "method", "database_location", "database_version"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    DATABASE_LOCATION_FIELD_NUMBER: _ClassVar[int]
    DATABASE_VERSION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    method: str
    database_location: str
    database_version: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., method: _Optional[str] = ..., database_location: _Optional[str] = ..., database_version: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BehaviorTreeStatusChange(_message.Message):
    __slots__ = ["timestamp", "node_name", "uid", "previous_status", "current_status"]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    NODE_NAME_FIELD_NUMBER: _ClassVar[int]
    UID_FIELD_NUMBER: _ClassVar[int]
    PREVIOUS_STATUS_FIELD_NUMBER: _ClassVar[int]
    CURRENT_STATUS_FIELD_NUMBER: _ClassVar[int]
    timestamp: _time_pb2.Time
    node_name: str
    uid: int
    previous_status: str
    current_status: str
    def __init__(self, timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., node_name: _Optional[str] = ..., uid: _Optional[int] = ..., previous_status: _Optional[str] = ..., current_status: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/controller_manager_msgs/srv/unload_controller.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/rolling/controller_manager_msgs/srv/unload_controller.proto\x12\x38make87_messages_ros2.rolling.controller_manager_msgs.srv\"\'\n\x17UnloadControllerRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"&\n\x18UnloadControllerResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.controller_manager_msgs.srv.unload_controller_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UNLOADCONTROLLERREQUEST']._serialized_start=142
  _globals['_UNLOADCONTROLLERREQUEST']._serialized_end=181
  _globals['_UNLOADCONTROLLERRESPONSE']._serialized_start=183
  _globals['_UNLOADCONTROLLERRESPONSE']._serialized_end=221
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NamedPose(_message.Message):
    __slots__ = ["name", "pose"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    name: str
    pose: _pose_pb2.Pose
    def __init__(self, name: _Optional[str] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/derived_object_msgs/msg/object_with_covariance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.derived_object_msgs.msg import solid_primitive_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_derived__object__msgs_dot_msg_dot_solid__primitive__with__covariance__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import accel_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_accel__with__covariance__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import polygon_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_polygon__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_twist__with__covariance__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/derived_object_msgs/msg/object_with_covariance.proto\x12\x33make87_messages_ros2.humble.derived_object_msgs.msg\x1a!make87_messages/core/header.proto\x1aYmake87_messages_ros2/humble/derived_object_msgs/msg/solid_primitive_with_covariance.proto\x1aImake87_messages_ros2/humble/geometry_msgs/msg/accel_with_covariance.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/polygon.proto\x1aHmake87_messages_ros2/humble/geometry_msgs/msg/pose_with_covariance.proto\x1aImake87_messages_ros2/humble/geometry_msgs/msg/twist_with_covariance.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xc3\x05\n\x14ObjectWithCovariance\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\n\n\x02id\x18\x03 \x01(\r\x12\x17\n\x0f\x64\x65tection_level\x18\x04 \x01(\r\x12\x19\n\x11object_classified\x18\x05 \x01(\x08\x12O\n\x04pose\x18\x06 \x01(\x0b\x32\x41.make87_messages_ros2.humble.geometry_msgs.msg.PoseWithCovariance\x12Q\n\x05twist\x18\x07 \x01(\x0b\x32\x42.make87_messages_ros2.humble.geometry_msgs.msg.TwistWithCovariance\x12Q\n\x05\x61\x63\x63\x65l\x18\x08 \x01(\x0b\x32\x42.make87_messages_ros2.humble.geometry_msgs.msg.AccelWithCovariance\x12G\n\x07polygon\x18\t \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Polygon\x12`\n\x05shape\x18\n \x01(\x0b\x32Q.make87_messages_ros2.humble.derived_object_msgs.msg.SolidPrimitiveWithCovariance\x12\x16\n\x0e\x63lassification\x18\x0b \x01(\r\x12 \n\x18\x63lassification_certainty\x18\x0c \x01(\r\x12\x1a\n\x12\x63lassification_age\x18\r \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.derived_object_msgs.msg.object_with_covariance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBJECTWITHCOVARIANCE']._serialized_start=604
  _globals['_OBJECTWITHCOVARIANCE']._serialized_end=1311
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GPSDetails(_message.Message):
    __slots__ = ["header", "ros2_header", "horizontal_dop", "position_dop", "fix_state", "vertical_accuracy", "horizontal_accuracy", "speed_accuracy", "num_gps_satellites_used", "num_glonass_satellites_used", "num_total_satellites_used", "gps_counter"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    HORIZONTAL_DOP_FIELD_NUMBER: _ClassVar[int]
    POSITION_DOP_FIELD_NUMBER: _ClassVar[int]
    FIX_STATE_FIELD_NUMBER: _ClassVar[int]
    VERTICAL_ACCURACY_FIELD_NUMBER: _ClassVar[int]
    HORIZONTAL_ACCURACY_FIELD_NUMBER: _ClassVar[int]
    SPEED_ACCURACY_FIELD_NUMBER: _ClassVar[int]
    NUM_GPS_SATELLITES_USED_FIELD_NUMBER: _ClassVar[int]
    NUM_GLONASS_SATELLITES_USED_FIELD_NUMBER: _ClassVar[int]
    NUM_TOTAL_SATELLITES_USED_FIELD_NUMBER: _ClassVar[int]
    GPS_COUNTER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    horizontal_dop: float
    position_dop: float
    fix_state: float
    vertical_accuracy: float
    horizontal_accuracy: float
    speed_accuracy: float
    num_gps_satellites_used: int
    num_glonass_satellites_used: int
    num_total_satellites_used: int
    gps_counter: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., horizontal_dop: _Optional[float] = ..., position_dop: _Optional[float] = ..., fix_state: _Optional[float] = ..., vertical_accuracy: _Optional[float] = ..., horizontal_accuracy: _Optional[float] = ..., speed_accuracy: _Optional[float] = ..., num_gps_satellites_used: _Optional[int] = ..., num_glonass_satellites_used: _Optional[int] = ..., num_total_satellites_used: _Optional[int] = ..., gps_counter: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GimbalManagerSetRoiRequest(_message.Message):
    __slots__ = ["header", "mode", "gimbal_device_id", "latitude", "longitude", "altitude", "pitch_offset", "roll_offset", "yaw_offset", "sysid"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    GIMBAL_DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_FIELD_NUMBER: _ClassVar[int]
    PITCH_OFFSET_FIELD_NUMBER: _ClassVar[int]
    ROLL_OFFSET_FIELD_NUMBER: _ClassVar[int]
    YAW_OFFSET_FIELD_NUMBER: _ClassVar[int]
    SYSID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    mode: int
    gimbal_device_id: int
    latitude: float
    longitude: float
    altitude: float
    pitch_offset: float
    roll_offset: float
    yaw_offset: float
    sysid: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., mode: _Optional[int] = ..., gimbal_device_id: _Optional[int] = ..., latitude: _Optional[float] = ..., longitude: _Optional[float] = ..., altitude: _Optional[float] = ..., pitch_offset: _Optional[float] = ..., roll_offset: _Optional[float] = ..., yaw_offset: _Optional[float] = ..., sysid: _Optional[int] = ...) -> None: ...

class GimbalManagerSetRoiResponse(_message.Message):
    __slots__ = ["header", "success", "result"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    result: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., result: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Button(_message.Message):
    __slots__ = ["header", "is_pressed", "last_start_pressed_time", "last_pressed_duration"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IS_PRESSED_FIELD_NUMBER: _ClassVar[int]
    LAST_START_PRESSED_TIME_FIELD_NUMBER: _ClassVar[int]
    LAST_PRESSED_DURATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    is_pressed: bool
    last_start_pressed_time: _time_pb2.Time
    last_pressed_duration: _duration_pb2.Duration
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., is_pressed: bool = ..., last_start_pressed_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., last_pressed_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_change_cull_pb2 as _schedule_change_cull_pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_participant_patch_pb2 as _schedule_participant_patch_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SchedulePatch(_message.Message):
    __slots__ = ["participants", "cull", "has_base_version", "base_version", "latest_version"]
    PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
    CULL_FIELD_NUMBER: _ClassVar[int]
    HAS_BASE_VERSION_FIELD_NUMBER: _ClassVar[int]
    BASE_VERSION_FIELD_NUMBER: _ClassVar[int]
    LATEST_VERSION_FIELD_NUMBER: _ClassVar[int]
    participants: _containers.RepeatedCompositeFieldContainer[_schedule_participant_patch_pb2.ScheduleParticipantPatch]
    cull: _containers.RepeatedCompositeFieldContainer[_schedule_change_cull_pb2.ScheduleChangeCull]
    has_base_version: bool
    base_version: int
    latest_version: int
    def __init__(self, participants: _Optional[_Iterable[_Union[_schedule_participant_patch_pb2.ScheduleParticipantPatch, _Mapping]]] = ..., cull: _Optional[_Iterable[_Union[_schedule_change_cull_pb2.ScheduleChangeCull, _Mapping]]] = ..., has_base_version: bool = ..., base_version: _Optional[int] = ..., latest_version: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.tuw_std_msgs.msg import parameter_pb2 as _parameter_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParameterArray(_message.Message):
    __slots__ = ["data"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: _containers.RepeatedCompositeFieldContainer[_parameter_pb2.Parameter]
    def __init__(self, data: _Optional[_Iterable[_Union[_parameter_pb2.Parameter, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_scan_xd/msg/nav_reflector_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/sick_scan_xd/msg/nav_reflector_data.proto\x12+make87_messages_ros2.jazzy.sick_scan_xd.msg\"\x93\x03\n\x10NAVReflectorData\x12\x1c\n\x14\x63\x61rtesian_data_valid\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x05\x12\t\n\x01y\x18\x03 \x01(\x05\x12\x18\n\x10polar_data_valid\x18\x04 \x01(\r\x12\x0c\n\x04\x64ist\x18\x05 \x01(\r\x12\x0b\n\x03phi\x18\x06 \x01(\r\x12 \n\x18opt_reflector_data_valid\x18\x07 \x01(\r\x12\x10\n\x08local_id\x18\x08 \x01(\r\x12\x11\n\tglobal_id\x18\t \x01(\r\x12\x0c\n\x04type\x18\n \x01(\r\x12\x10\n\x08sub_type\x18\x0b \x01(\r\x12\x0f\n\x07quality\x18\x0c \x01(\r\x12\x11\n\ttimestamp\x18\r \x01(\r\x12\x0c\n\x04size\x18\x0e \x01(\r\x12\x11\n\thit_count\x18\x0f \x01(\r\x12\x11\n\tmean_echo\x18\x10 \x01(\r\x12\x13\n\x0bstart_index\x18\x11 \x01(\r\x12\x11\n\tend_index\x18\x12 \x01(\r\x12\x11\n\tpos_valid\x18\x13 \x01(\x05\x12\r\n\x05pos_x\x18\x14 \x01(\x02\x12\r\n\x05pos_y\x18\x15 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_scan_xd.msg.nav_reflector_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NAVREFLECTORDATA']._serialized_start=118
  _globals['_NAVREFLECTORDATA']._serialized_end=521
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/can_msgs/msg/frame.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3make87_messages_ros2/jazzy/can_msgs/msg/frame.proto\x12\'make87_messages_ros2.jazzy.can_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xa6\x01\n\x05\x46rame\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\n\n\x02id\x18\x02 \x01(\r\x12\x0e\n\x06is_rtr\x18\x03 \x01(\x08\x12\x13\n\x0bis_extended\x18\x04 \x01(\x08\x12\x10\n\x08is_error\x18\x05 \x01(\x08\x12\x0b\n\x03\x64lc\x18\x06 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x07 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.can_msgs.msg.frame_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FRAME']._serialized_start=151
  _globals['_FRAME']._serialized_end=317
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import point2_df_pb2 as _point2_df_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Object2280(_message.Message):
    __slots__ = ["id", "tracking_model", "mobility_of_dyn_object_detected", "motion_model_validated", "object_age", "timestamp", "object_prediction_age", "classification", "classification_certainty", "classification_age", "object_box_center", "object_box_center_sigma", "object_box_size", "object_box_orientation_angle", "object_box_orientation_angle_sigma", "relative_velocity", "relative_velocity_sigma", "absolute_velocity", "absolute_velocity_sigma", "number_of_contour_points", "closest_point_index", "reference_point_location", "reference_point_coordinate", "reference_point_coordinate_sigma", "reference_point_position_correction_coefficient", "object_priority", "object_existence_measurement", "contour_point_list"]
    ID_FIELD_NUMBER: _ClassVar[int]
    TRACKING_MODEL_FIELD_NUMBER: _ClassVar[int]
    MOBILITY_OF_DYN_OBJECT_DETECTED_FIELD_NUMBER: _ClassVar[int]
    MOTION_MODEL_VALIDATED_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AGE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    OBJECT_PREDICTION_AGE_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_CERTAINTY_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_AGE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_BOX_CENTER_FIELD_NUMBER: _ClassVar[int]
    OBJECT_BOX_CENTER_SIGMA_FIELD_NUMBER: _ClassVar[int]
    OBJECT_BOX_SIZE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_BOX_ORIENTATION_ANGLE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_BOX_ORIENTATION_ANGLE_SIGMA_FIELD_NUMBER: _ClassVar[int]
    RELATIVE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    RELATIVE_VELOCITY_SIGMA_FIELD_NUMBER: _ClassVar[int]
    ABSOLUTE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    ABSOLUTE_VELOCITY_SIGMA_FIELD_NUMBER: _ClassVar[int]
    NUMBER_OF_CONTOUR_POINTS_FIELD_NUMBER: _ClassVar[int]
    CLOSEST_POINT_INDEX_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_POINT_LOCATION_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_POINT_COORDINATE_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_POINT_COORDINATE_SIGMA_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_POINT_POSITION_CORRECTION_COEFFICIENT_FIELD_NUMBER: _ClassVar[int]
    OBJECT_PRIORITY_FIELD_NUMBER: _ClassVar[int]
    OBJECT_EXISTENCE_MEASUREMENT_FIELD_NUMBER: _ClassVar[int]
    CONTOUR_POINT_LIST_FIELD_NUMBER: _ClassVar[int]
    id: int
    tracking_model: int
    mobility_of_dyn_object_detected: bool
    motion_model_validated: bool
    object_age: int
    timestamp: _time_pb2.Time
    object_prediction_age: int
    classification: int
    classification_certainty: int
    classification_age: int
    object_box_center: _point2_df_pb2.Point2Df
    object_box_center_sigma: _point2_df_pb2.Point2Df
    object_box_size: _point2_df_pb2.Point2Df
    object_box_orientation_angle: float
    object_box_orientation_angle_sigma: float
    relative_velocity: _point2_df_pb2.Point2Df
    relative_velocity_sigma: _point2_df_pb2.Point2Df
    absolute_velocity: _point2_df_pb2.Point2Df
    absolute_velocity_sigma: _point2_df_pb2.Point2Df
    number_of_contour_points: int
    closest_point_index: int
    reference_point_location: int
    reference_point_coordinate: _point2_df_pb2.Point2Df
    reference_point_coordinate_sigma: _point2_df_pb2.Point2Df
    reference_point_position_correction_coefficient: float
    object_priority: int
    object_existence_measurement: float
    contour_point_list: _containers.RepeatedCompositeFieldContainer[_point2_df_pb2.Point2Df]
    def __init__(self, id: _Optional[int] = ..., tracking_model: _Optional[int] = ..., mobility_of_dyn_object_detected: bool = ..., motion_model_validated: bool = ..., object_age: _Optional[int] = ..., timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., object_prediction_age: _Optional[int] = ..., classification: _Optional[int] = ..., classification_certainty: _Optional[int] = ..., classification_age: _Optional[int] = ..., object_box_center: _Optional[_Union[_point2_df_pb2.Point2Df, _Mapping]] = ..., object_box_center_sigma: _Optional[_Union[_point2_df_pb2.Point2Df, _Mapping]] = ..., object_box_size: _Optional[_Union[_point2_df_pb2.Point2Df, _Mapping]] = ..., object_box_orientation_angle: _Optional[float] = ..., object_box_orientation_angle_sigma: _Optional[float] = ..., relative_velocity: _Optional[_Union[_point2_df_pb2.Point2Df, _Mapping]] = ..., relative_velocity_sigma: _Optional[_Union[_point2_df_pb2.Point2Df, _Mapping]] = ..., absolute_velocity: _Optional[_Union[_point2_df_pb2.Point2Df, _Mapping]] = ..., absolute_velocity_sigma: _Optional[_Union[_point2_df_pb2.Point2Df, _Mapping]] = ..., number_of_contour_points: _Optional[int] = ..., closest_point_index: _Optional[int] = ..., reference_point_location: _Optional[int] = ..., reference_point_coordinate: _Optional[_Union[_point2_df_pb2.Point2Df, _Mapping]] = ..., reference_point_coordinate_sigma: _Optional[_Union[_point2_df_pb2.Point2Df, _Mapping]] = ..., reference_point_position_correction_coefficient: _Optional[float] = ..., object_priority: _Optional[int] = ..., object_existence_measurement: _Optional[float] = ..., contour_point_list: _Optional[_Iterable[_Union[_point2_df_pb2.Point2Df, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GALAuthStatus(_message.Message):
    __slots__ = ["header", "block_header", "osnma_status", "trusted_time_delta", "gal_active_mask", "gal_authentic_mask", "gps_active_mask", "gps_authentic_mask"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    OSNMA_STATUS_FIELD_NUMBER: _ClassVar[int]
    TRUSTED_TIME_DELTA_FIELD_NUMBER: _ClassVar[int]
    GAL_ACTIVE_MASK_FIELD_NUMBER: _ClassVar[int]
    GAL_AUTHENTIC_MASK_FIELD_NUMBER: _ClassVar[int]
    GPS_ACTIVE_MASK_FIELD_NUMBER: _ClassVar[int]
    GPS_AUTHENTIC_MASK_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    block_header: _block_header_pb2.BlockHeader
    osnma_status: int
    trusted_time_delta: float
    gal_active_mask: int
    gal_authentic_mask: int
    gps_active_mask: int
    gps_authentic_mask: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., osnma_status: _Optional[int] = ..., trusted_time_delta: _Optional[float] = ..., gal_active_mask: _Optional[int] = ..., gal_authentic_mask: _Optional[int] = ..., gps_active_mask: _Optional[int] = ..., gps_authentic_mask: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/set_model_configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/jazzy/gazebo_msgs/srv/set_model_configuration.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\"y\n\x1cSetModelConfigurationRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x17\n\x0furdf_param_name\x18\x02 \x01(\t\x12\x13\n\x0bjoint_names\x18\x03 \x03(\t\x12\x17\n\x0fjoint_positions\x18\x04 \x03(\x01\"H\n\x1dSetModelConfigurationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0estatus_message\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.set_model_configuration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETMODELCONFIGURATIONREQUEST']._serialized_start=120
  _globals['_SETMODELCONFIGURATIONREQUEST']._serialized_end=241
  _globals['_SETMODELCONFIGURATIONRESPONSE']._serialized_start=243
  _globals['_SETMODELCONFIGURATIONRESPONSE']._serialized_end=315
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DetectedRadarObject(_message.Message):
    __slots__ = ["id", "sensor_aim", "sensor_right", "sensor_position", "sensor_velocity", "sensor_angle", "object_position", "object_velocity", "object_relative_position", "object_relative_velocity", "object_collider_size", "object_state", "new_detection"]
    ID_FIELD_NUMBER: _ClassVar[int]
    SENSOR_AIM_FIELD_NUMBER: _ClassVar[int]
    SENSOR_RIGHT_FIELD_NUMBER: _ClassVar[int]
    SENSOR_POSITION_FIELD_NUMBER: _ClassVar[int]
    SENSOR_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    SENSOR_ANGLE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_POSITION_FIELD_NUMBER: _ClassVar[int]
    OBJECT_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    OBJECT_RELATIVE_POSITION_FIELD_NUMBER: _ClassVar[int]
    OBJECT_RELATIVE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    OBJECT_COLLIDER_SIZE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_STATE_FIELD_NUMBER: _ClassVar[int]
    NEW_DETECTION_FIELD_NUMBER: _ClassVar[int]
    id: int
    sensor_aim: _vector3_pb2.Vector3
    sensor_right: _vector3_pb2.Vector3
    sensor_position: _point_pb2.Point
    sensor_velocity: _vector3_pb2.Vector3
    sensor_angle: float
    object_position: _point_pb2.Point
    object_velocity: _vector3_pb2.Vector3
    object_relative_position: _point_pb2.Point
    object_relative_velocity: _vector3_pb2.Vector3
    object_collider_size: _vector3_pb2.Vector3
    object_state: int
    new_detection: bool
    def __init__(self, id: _Optional[int] = ..., sensor_aim: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., sensor_right: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., sensor_position: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., sensor_velocity: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., sensor_angle: _Optional[float] = ..., object_position: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., object_velocity: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., object_relative_position: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., object_relative_velocity: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., object_collider_size: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., object_state: _Optional[int] = ..., new_detection: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.ublox_ubx_msgs.msg import sig_flags_pb2 as _sig_flags_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SigData(_message.Message):
    __slots__ = ["header", "gnss_id", "sv_id", "sig_id", "freq_id", "pr_res", "cno", "quality_ind", "corr_source", "iono_model", "sig_flags"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    GNSS_ID_FIELD_NUMBER: _ClassVar[int]
    SV_ID_FIELD_NUMBER: _ClassVar[int]
    SIG_ID_FIELD_NUMBER: _ClassVar[int]
    FREQ_ID_FIELD_NUMBER: _ClassVar[int]
    PR_RES_FIELD_NUMBER: _ClassVar[int]
    CNO_FIELD_NUMBER: _ClassVar[int]
    QUALITY_IND_FIELD_NUMBER: _ClassVar[int]
    CORR_SOURCE_FIELD_NUMBER: _ClassVar[int]
    IONO_MODEL_FIELD_NUMBER: _ClassVar[int]
    SIG_FLAGS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    gnss_id: int
    sv_id: int
    sig_id: int
    freq_id: int
    pr_res: int
    cno: int
    quality_ind: int
    corr_source: int
    iono_model: int
    sig_flags: _sig_flags_pb2.SigFlags
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., gnss_id: _Optional[int] = ..., sv_id: _Optional[int] = ..., sig_id: _Optional[int] = ..., freq_id: _Optional[int] = ..., pr_res: _Optional[int] = ..., cno: _Optional[int] = ..., quality_ind: _Optional[int] = ..., corr_source: _Optional[int] = ..., iono_model: _Optional[int] = ..., sig_flags: _Optional[_Union[_sig_flags_pb2.SigFlags, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/srv/get_motion_sequence.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import motion_sequence_request_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_motion__sequence__request__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import motion_sequence_response_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_motion__sequence__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/moveit_msgs/srv/get_motion_sequence.proto\x12,make87_messages_ros2.rolling.moveit_msgs.srv\x1aJmake87_messages_ros2/rolling/moveit_msgs/msg/motion_sequence_request.proto\x1aKmake87_messages_ros2/rolling/moveit_msgs/msg/motion_sequence_response.proto\"p\n\x18GetMotionSequenceRequest\x12T\n\x07request\x18\x01 \x01(\x0b\x32\x43.make87_messages_ros2.rolling.moveit_msgs.msg.MotionSequenceRequest\"s\n\x19GetMotionSequenceResponse\x12V\n\x08response\x18\x01 \x01(\x0b\x32\x44.make87_messages_ros2.rolling.moveit_msgs.msg.MotionSequenceResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.srv.get_motion_sequence_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETMOTIONSEQUENCEREQUEST']._serialized_start=273
  _globals['_GETMOTIONSEQUENCEREQUEST']._serialized_end=385
  _globals['_GETMOTIONSEQUENCERESPONSE']._serialized_start=387
  _globals['_GETMOTIONSEQUENCERESPONSE']._serialized_end=502
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavHPPosLLH(_message.Message):
    __slots__ = ["header", "version", "invalid_lon", "invalid_lat", "invalid_height", "invalid_hmsl", "invalid_lon_hp", "invalid_lat_hp", "invalid_height_hp", "invalid_hmsl_hp", "itow", "lon", "lat", "height", "hmsl", "lon_hp", "lat_hp", "height_hp", "hmsl_hp", "h_acc", "v_acc"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    INVALID_LON_FIELD_NUMBER: _ClassVar[int]
    INVALID_LAT_FIELD_NUMBER: _ClassVar[int]
    INVALID_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INVALID_HMSL_FIELD_NUMBER: _ClassVar[int]
    INVALID_LON_HP_FIELD_NUMBER: _ClassVar[int]
    INVALID_LAT_HP_FIELD_NUMBER: _ClassVar[int]
    INVALID_HEIGHT_HP_FIELD_NUMBER: _ClassVar[int]
    INVALID_HMSL_HP_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    LON_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    HMSL_FIELD_NUMBER: _ClassVar[int]
    LON_HP_FIELD_NUMBER: _ClassVar[int]
    LAT_HP_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_HP_FIELD_NUMBER: _ClassVar[int]
    HMSL_HP_FIELD_NUMBER: _ClassVar[int]
    H_ACC_FIELD_NUMBER: _ClassVar[int]
    V_ACC_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    version: int
    invalid_lon: bool
    invalid_lat: bool
    invalid_height: bool
    invalid_hmsl: bool
    invalid_lon_hp: bool
    invalid_lat_hp: bool
    invalid_height_hp: bool
    invalid_hmsl_hp: bool
    itow: int
    lon: int
    lat: int
    height: int
    hmsl: int
    lon_hp: int
    lat_hp: int
    height_hp: int
    hmsl_hp: int
    h_acc: int
    v_acc: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., version: _Optional[int] = ..., invalid_lon: bool = ..., invalid_lat: bool = ..., invalid_height: bool = ..., invalid_hmsl: bool = ..., invalid_lon_hp: bool = ..., invalid_lat_hp: bool = ..., invalid_height_hp: bool = ..., invalid_hmsl_hp: bool = ..., itow: _Optional[int] = ..., lon: _Optional[int] = ..., lat: _Optional[int] = ..., height: _Optional[int] = ..., hmsl: _Optional[int] = ..., lon_hp: _Optional[int] = ..., lat_hp: _Optional[int] = ..., height_hp: _Optional[int] = ..., hmsl_hp: _Optional[int] = ..., h_acc: _Optional[int] = ..., v_acc: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.controller_manager_msgs.msg import hardware_interface_pb2 as _hardware_interface_pb2
from make87_messages_ros2.humble.lifecycle_msgs.msg import state_pb2 as _state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HardwareComponentState(_message.Message):
    __slots__ = ["header", "name", "type", "class_type", "state", "command_interfaces", "state_interfaces"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CLASS_TYPE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    COMMAND_INTERFACES_FIELD_NUMBER: _ClassVar[int]
    STATE_INTERFACES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    type: str
    class_type: str
    state: _state_pb2.State
    command_interfaces: _containers.RepeatedCompositeFieldContainer[_hardware_interface_pb2.HardwareInterface]
    state_interfaces: _containers.RepeatedCompositeFieldContainer[_hardware_interface_pb2.HardwareInterface]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ..., type: _Optional[str] = ..., class_type: _Optional[str] = ..., state: _Optional[_Union[_state_pb2.State, _Mapping]] = ..., command_interfaces: _Optional[_Iterable[_Union[_hardware_interface_pb2.HardwareInterface, _Mapping]]] = ..., state_interfaces: _Optional[_Iterable[_Union[_hardware_interface_pb2.HardwareInterface, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/gazebo_msgs/srv/set_link_properties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/humble/gazebo_msgs/srv/set_link_properties.proto\x12+make87_messages_ros2.humble.gazebo_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\"\x8f\x02\n\x18SetLinkPropertiesRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x11\n\tlink_name\x18\x02 \x01(\t\x12@\n\x03\x63om\x18\x03 \x01(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12\x14\n\x0cgravity_mode\x18\x04 \x01(\x08\x12\x0c\n\x04mass\x18\x05 \x01(\x01\x12\x0b\n\x03ixx\x18\x06 \x01(\x01\x12\x0b\n\x03ixy\x18\x07 \x01(\x01\x12\x0b\n\x03ixz\x18\x08 \x01(\x01\x12\x0b\n\x03iyy\x18\t \x01(\x01\x12\x0b\n\x03iyz\x18\n \x01(\x01\x12\x0b\n\x03izz\x18\x0b \x01(\x01\"r\n\x19SetLinkPropertiesResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x16\n\x0estatus_message\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.gazebo_msgs.srv.set_link_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETLINKPROPERTIESREQUEST']._serialized_start=212
  _globals['_SETLINKPROPERTIESREQUEST']._serialized_end=483
  _globals['_SETLINKPROPERTIESRESPONSE']._serialized_start=485
  _globals['_SETLINKPROPERTIESRESPONSE']._serialized_end=599
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MountConfigureRequest(_message.Message):
    __slots__ = ["header", "ros2_header", "mode", "stabilize_roll", "stabilize_pitch", "stabilize_yaw", "roll_input", "pitch_input", "yaw_input"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    STABILIZE_ROLL_FIELD_NUMBER: _ClassVar[int]
    STABILIZE_PITCH_FIELD_NUMBER: _ClassVar[int]
    STABILIZE_YAW_FIELD_NUMBER: _ClassVar[int]
    ROLL_INPUT_FIELD_NUMBER: _ClassVar[int]
    PITCH_INPUT_FIELD_NUMBER: _ClassVar[int]
    YAW_INPUT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    mode: int
    stabilize_roll: bool
    stabilize_pitch: bool
    stabilize_yaw: bool
    roll_input: int
    pitch_input: int
    yaw_input: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., mode: _Optional[int] = ..., stabilize_roll: bool = ..., stabilize_pitch: bool = ..., stabilize_yaw: bool = ..., roll_input: _Optional[int] = ..., pitch_input: _Optional[int] = ..., yaw_input: _Optional[int] = ...) -> None: ...

class MountConfigureResponse(_message.Message):
    __slots__ = ["header", "success", "result"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    result: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., result: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/flexbe_msgs/msg/behavior_selection.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.flexbe_msgs.msg import behavior_modification_pb2 as make87__messages__ros2_dot_humble_dot_flexbe__msgs_dot_msg_dot_behavior__modification__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/flexbe_msgs/msg/behavior_selection.proto\x12+make87_messages_ros2.humble.flexbe_msgs.msg\x1a!make87_messages/core/header.proto\x1aGmake87_messages_ros2/humble/flexbe_msgs/msg/behavior_modification.proto\"\xae\x02\n\x11\x42\x65haviorSelection\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x14\n\x0c\x62\x65havior_key\x18\x02 \x01(\x05\x12\x13\n\x0b\x62\x65havior_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x61utonomy_level\x18\x04 \x01(\r\x12\x10\n\x08\x61rg_keys\x18\x05 \x03(\t\x12\x12\n\narg_values\x18\x06 \x03(\t\x12\x12\n\ninput_keys\x18\x07 \x03(\t\x12\x14\n\x0cinput_values\x18\x08 \x03(\t\x12X\n\rmodifications\x18\t \x03(\x0b\x32\x41.make87_messages_ros2.humble.flexbe_msgs.msg.BehaviorModificationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.flexbe_msgs.msg.behavior_selection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BEHAVIORSELECTION']._serialized_start=226
  _globals['_BEHAVIORSELECTION']._serialized_end=528
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/robot_calibration_msgs/msg/observation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_stamped_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_point__stamped__pb2
from make87_messages_ros2.humble.robot_calibration_msgs.msg import extended_camera_info_pb2 as make87__messages__ros2_dot_humble_dot_robot__calibration__msgs_dot_msg_dot_extended__camera__info__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import image_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_image__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/humble/robot_calibration_msgs/msg/observation.proto\x12\x36make87_messages_ros2.humble.robot_calibration_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x41make87_messages_ros2/humble/geometry_msgs/msg/point_stamped.proto\x1aQmake87_messages_ros2/humble/robot_calibration_msgs/msg/extended_camera_info.proto\x1a\x37make87_messages_ros2/humble/sensor_msgs/msg/image.proto\x1a>make87_messages_ros2/humble/sensor_msgs/msg/point_cloud2.proto\"\x90\x03\n\x0bObservation\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x13\n\x0bsensor_name\x18\x02 \x01(\t\x12M\n\x08\x66\x65\x61tures\x18\x03 \x03(\x0b\x32;.make87_messages_ros2.humble.geometry_msgs.msg.PointStamped\x12\x63\n\x0f\x65xt_camera_info\x18\x04 \x01(\x0b\x32J.make87_messages_ros2.humble.robot_calibration_msgs.msg.ExtendedCameraInfo\x12G\n\x05\x63loud\x18\x05 \x01(\x0b\x32\x38.make87_messages_ros2.humble.sensor_msgs.msg.PointCloud2\x12\x41\n\x05image\x18\x06 \x01(\x0b\x32\x32.make87_messages_ros2.humble.sensor_msgs.msg.Imageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.robot_calibration_msgs.msg.observation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OBSERVATION']._serialized_start=439
  _globals['_OBSERVATION']._serialized_end=839
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UserInputMenus(_message.Message):
    __slots__ = ["header", "str_whl_left_btn_left", "str_whl_left_btn_down", "str_whl_left_btn_right", "str_whl_left_btn_up", "str_whl_left_btn_ok", "str_whl_right_btn_left", "str_whl_right_btn_down", "str_whl_right_btn_right", "str_whl_right_btn_up", "str_whl_right_btn_ok", "cntr_cons_btn_left", "cntr_cons_btn_down", "cntr_cons_btn_right", "cntr_cons_btn_up", "cntr_cons_btn_ok"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STR_WHL_LEFT_BTN_LEFT_FIELD_NUMBER: _ClassVar[int]
    STR_WHL_LEFT_BTN_DOWN_FIELD_NUMBER: _ClassVar[int]
    STR_WHL_LEFT_BTN_RIGHT_FIELD_NUMBER: _ClassVar[int]
    STR_WHL_LEFT_BTN_UP_FIELD_NUMBER: _ClassVar[int]
    STR_WHL_LEFT_BTN_OK_FIELD_NUMBER: _ClassVar[int]
    STR_WHL_RIGHT_BTN_LEFT_FIELD_NUMBER: _ClassVar[int]
    STR_WHL_RIGHT_BTN_DOWN_FIELD_NUMBER: _ClassVar[int]
    STR_WHL_RIGHT_BTN_RIGHT_FIELD_NUMBER: _ClassVar[int]
    STR_WHL_RIGHT_BTN_UP_FIELD_NUMBER: _ClassVar[int]
    STR_WHL_RIGHT_BTN_OK_FIELD_NUMBER: _ClassVar[int]
    CNTR_CONS_BTN_LEFT_FIELD_NUMBER: _ClassVar[int]
    CNTR_CONS_BTN_DOWN_FIELD_NUMBER: _ClassVar[int]
    CNTR_CONS_BTN_RIGHT_FIELD_NUMBER: _ClassVar[int]
    CNTR_CONS_BTN_UP_FIELD_NUMBER: _ClassVar[int]
    CNTR_CONS_BTN_OK_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    str_whl_left_btn_left: bool
    str_whl_left_btn_down: bool
    str_whl_left_btn_right: bool
    str_whl_left_btn_up: bool
    str_whl_left_btn_ok: bool
    str_whl_right_btn_left: bool
    str_whl_right_btn_down: bool
    str_whl_right_btn_right: bool
    str_whl_right_btn_up: bool
    str_whl_right_btn_ok: bool
    cntr_cons_btn_left: bool
    cntr_cons_btn_down: bool
    cntr_cons_btn_right: bool
    cntr_cons_btn_up: bool
    cntr_cons_btn_ok: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., str_whl_left_btn_left: bool = ..., str_whl_left_btn_down: bool = ..., str_whl_left_btn_right: bool = ..., str_whl_left_btn_up: bool = ..., str_whl_left_btn_ok: bool = ..., str_whl_right_btn_left: bool = ..., str_whl_right_btn_down: bool = ..., str_whl_right_btn_right: bool = ..., str_whl_right_btn_up: bool = ..., str_whl_right_btn_ok: bool = ..., cntr_cons_btn_left: bool = ..., cntr_cons_btn_down: bool = ..., cntr_cons_btn_right: bool = ..., cntr_cons_btn_up: bool = ..., cntr_cons_btn_ok: bool = ...) -> None: ...



from make87_messages_ros2.rolling.rosbridge_test_msgs.msg import test_float32_bounded_array_pb2 as _test_float32_bounded_array_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TestNestedBoundedArray(_message.Message):
    __slots__ = ["data"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: _test_float32_bounded_array_pb2.TestFloat32BoundedArray
    def __init__(self, data: _Optional[_Union[_test_float32_bounded_array_pb2.TestFloat32BoundedArray, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_door_msgs.msg import session_pb2 as _session_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DoorSessions(_message.Message):
    __slots__ = ["door_name", "sessions"]
    DOOR_NAME_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    door_name: str
    sessions: _containers.RepeatedCompositeFieldContainer[_session_pb2.Session]
    def __init__(self, door_name: _Optional[str] = ..., sessions: _Optional[_Iterable[_Union[_session_pb2.Session, _Mapping]]] = ...) -> None: ...
